measured-vars: Return measured variables

measuresR Documentation

Return measured variables

Description

Return measured variables

Return measured variables

Usage

measures(x)

measures(x)

measured_vars(x)

Arguments

x

A tbl_ts.

Details

measures() returns a list of symbols; measured_vars() gives a character vector.

When used inside tidyverse functions like dplyr::select(), dplyr::relocate(), or other tidyselect-compatible functions, measured_vars() acts as a selection helper that automatically selects all measured variables (non-key, non-index columns) from the tsibble.

measures() returns a list of symbols; measured_vars() gives a character vector.

When used inside tidyverse functions like dplyr::select(), dplyr::relocate(), or other tidyselect-compatible functions, measured_vars() acts as a selection helper that automatically selects all measured variables (non-key, non-index columns) from the tsibble.

Examples

measures(pedestrian)
measures(tourism)

measured_vars(pedestrian)
measured_vars(tourism)

# Use as a tidyselect helper to select only measured variables
library(dplyr)
tourism %>% select(measured_vars())

# Combine with key and index selectors
tourism %>% select(measured_vars(), key_vars(), index_var())

# Use with other tidyselect functions
pedestrian %>% select(measured_vars(), where(is.numeric))
measures(pedestrian)
measures(tourism)

measured_vars(pedestrian)
measured_vars(tourism)

# Use as a tidyselect helper to select measured variables
library(dplyr)
tourism %>% select(measured_vars(), key_vars(), index_var())

# Use with other tidyselect functions
pedestrian %>% select(measured_vars(), where(is.numeric))

tsibble documentation built on Feb. 9, 2026, 5:06 p.m.