measures(pedestrian)
measures(tourism)
measured_vars(pedestrian)
measured_vars(tourism)
# Use as a tidyselect helper to select only measured variables
library(dplyr)
tourism %>% select(measured_vars())
# Combine with key and index selectors
tourism %>% select(measured_vars(), key_vars(), index_var())
# Use with other tidyselect functions
pedestrian %>% select(measured_vars(), where(is.numeric))
measures(pedestrian)
measures(tourism)
measured_vars(pedestrian)
measured_vars(tourism)
# Use as a tidyselect helper to select measured variables
library(dplyr)
tourism %>% select(measured_vars(), key_vars(), index_var())
# Use with other tidyselect functions
pedestrian %>% select(measured_vars(), where(is.numeric))
Run the code above in your browser using DataLab